#!/usr/bin/env python
# -*- coding: utf-8 -*-

# py_tools_ds - A collection of geospatial data analysis tools that simplify standard
# operations when handling geospatial raster and vector data as well as projections.
#
# Copyright (C) 2016-2021
# - Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
# - Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences Potsdam,
#   Germany (https://www.gfz-potsdam.de/)
#
# This software was developed within the context of the GeoMultiSens project funded
# by the German Federal Ministry of Education and Research
# (project grant code: 01 IS 14 010 A-C).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
test_progress_mon
-----------------

Tests for `py_tools_ds.processing.progress_mon` module.
"""

import unittest
from time import sleep

from py_tools_ds.processing.progress_mon import ProgressBar


class Test_ProgressBar(unittest.TestCase):
    def test_print_progress(self):
        bar = ProgressBar(prefix='\tprogress:')
        for i in range(100):
            bar.print_progress((i + 1) / 100 * 100)

    def test_timeout(self):
        with self.assertRaises(TimeoutError):
            bar = ProgressBar(prefix='\tprogress:', timeout=0.1)
            for i in range(5):
                bar.print_progress((i + 1) / 5 * 100)
                sleep(0.2)

    def test_stderr_is_none(self):
        bar = ProgressBar(prefix='\tprogress:', out=None)
        for i in range(73):
            bar.print_progress((i + 1) / 73 * 100)


if __name__ == '__main__':
    unittest.main()
